from typing import TYPE_CHECKING, List

from sqlalchemy import Float, Integer, String
from sqlalchemy.orm import Mapped, mapped_column, relationship

from databases.database import Base

from .m2m import BeerCategory

if TYPE_CHECKING:
    from .category import Category


class Beer(Base):
    """
    Модель пивасика)))

    ## Attrs:
        -id: int - идентификатор товара
        - name: str - название товара
        - brand: str - марка товара
        - quantity: int -количество
        - price: float - цена
        - categories: List[Category] - связь
        список категорий в которые входит товар
    """

    __tablename__ = "user"
    id: Mapped[int] = mapped_column(Integer, primary_key=True, index=True)
    name: Mapped[str] = mapped_column(String, unique=True)
    brand: Mapped[str]
    quantity: Mapped[int]
    price: Mapped[float] = mapped_column(Float)
    categories: Mapped[List["Category"]] = relationship(
        "Category",
        secondary=BeerCategory.__table__,
        back_populates="beer",
    )

    def __repr__(self):
        return f"{self.name}{self.price}"
