from typing import TYPE_CHECKING, List

from sqlalchemy import Integer, String
from sqlalchemy.orm import Mapped, mapped_column, relationship

from databases.database import Base

from .m2m import BeerCategory

if TYPE_CHECKING:
    from .beer import Beer


class Category(Base):
    """
    Модель категории

    ## Attrs:
        - id: int - идентификатор категории
        - name: str - название категории
        - beer: List[Beer] - связь пиво в категории
    """

    __tablename__ = "catrgory"

    id: Mapped[int] = mapped_column(Integer, primary_key=True, index=True)
    name: Mapped[str] = mapped_column(String, unique=True)
    beer: Mapped[List["Beer"]] = relationship(
        "Beer",
        secondary=BeerCategory.__table__,
        back_populates="categories",
    )

    def __repr__(self):
        return f"{self.name}"
